import java.io.*;
import java.util.*;

import edu.uci.ics.jung.graph.*;

import net.deterlab.abac.Role;
import net.deterlab.abac.Identity;
import net.deterlab.abac.Credential;
import net.deterlab.abac.CredentialFactory;
import net.deterlab.abac.GENICredential;

import java.security.KeyPair;


/**
 * Simple test of the native Java implementation of ABAC. Loads credentials
 * from an rt0 file and runs a query against them.
 */
public class XMLExample {

    public static void writeCombinedIdentity(Identity i) throws IOException, FileNotFoundException {
	FileOutputStream f = new FileOutputStream(new File("./example/" + 
		    i.getName() + ".pem"));

	i.write(f);
	i.writePrivateKey(f);
    }
    public static void main(String[] args) throws IOException {
	try {
	    Identity acme = new Identity("Acme");
	    Identity globotron = new Identity("Globotron");
	    Identity alice = new Identity("Alice");
	    Identity bob = new Identity("Bob");
	    Vector<Identity> ids = new Vector<Identity>();
	    Vector<Credential> creds = new Vector<Credential>();
	    Collections.addAll(ids, acme, globotron, alice, bob);

	    for ( Identity i: ids) 
		writeCombinedIdentity(i);


	    GENICredential c = new GENICredential(
		    new Role(acme.getKeyID() + ".experiment_create"),
		    new Role(acme.getKeyID() + ".partner.experiment_create"));
	    c.make_cert(acme);
	    creds.add(c);
	    c = new GENICredential(
		    new Role(acme.getKeyID() + ".partner"),
		    new Role(globotron.getKeyID()));
	    c.make_cert(acme);
	    creds.add(c);
	    c = new GENICredential(
		    new Role(globotron.getKeyID() + ".experiment_create"),
		    new Role(globotron.getKeyID() + ".admin.power_user"));
	    c.make_cert(globotron);
	    creds.add(c);
	    c = new GENICredential(
		    new Role(globotron.getKeyID() + ".admin"),
		    new Role(alice.getKeyID()));
	    c.make_cert(globotron);
	    creds.add(c);
	    c = new GENICredential(
		    new Role(alice.getKeyID() + ".power_user"),
		    new Role(bob.getKeyID()));
	    c.make_cert(alice);
	    creds.add(c);

	    int i =0;
	    for (Credential cc: creds) {
		cc.write("./example/e" + i + ".xml");
		i ++;
	    }

	}
	catch (Exception e) {
	    e.printStackTrace();
	}

    }
}
